# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service (0.4.14)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsTopicResponse(Model):
    """Models topic response (models.TopicResponse)

    Properties:
        created_at: (createdAt) REQUIRED int

        created_by: (createdBy) REQUIRED str

        last_message_at: (lastMessageAt) REQUIRED int

        name: (name) REQUIRED str

        namespace: (namespace) REQUIRED str

        topic_id: (topicId) REQUIRED str

        type_: (type) REQUIRED str
    """

    # region fields

    created_at: int  # REQUIRED
    created_by: str  # REQUIRED
    last_message_at: int  # REQUIRED
    name: str  # REQUIRED
    namespace: str  # REQUIRED
    topic_id: str  # REQUIRED
    type_: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: int) -> ModelsTopicResponse:
        self.created_at = value
        return self

    def with_created_by(self, value: str) -> ModelsTopicResponse:
        self.created_by = value
        return self

    def with_last_message_at(self, value: int) -> ModelsTopicResponse:
        self.last_message_at = value
        return self

    def with_name(self, value: str) -> ModelsTopicResponse:
        self.name = value
        return self

    def with_namespace(self, value: str) -> ModelsTopicResponse:
        self.namespace = value
        return self

    def with_topic_id(self, value: str) -> ModelsTopicResponse:
        self.topic_id = value
        return self

    def with_type(self, value: str) -> ModelsTopicResponse:
        self.type_ = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = int(self.created_at)
        elif include_empty:
            result["createdAt"] = 0
        if hasattr(self, "created_by"):
            result["createdBy"] = str(self.created_by)
        elif include_empty:
            result["createdBy"] = ""
        if hasattr(self, "last_message_at"):
            result["lastMessageAt"] = int(self.last_message_at)
        elif include_empty:
            result["lastMessageAt"] = 0
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "topic_id"):
            result["topicId"] = str(self.topic_id)
        elif include_empty:
            result["topicId"] = ""
        if hasattr(self, "type_"):
            result["type"] = str(self.type_)
        elif include_empty:
            result["type"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: int,
        created_by: str,
        last_message_at: int,
        name: str,
        namespace: str,
        topic_id: str,
        type_: str,
        **kwargs,
    ) -> ModelsTopicResponse:
        instance = cls()
        instance.created_at = created_at
        instance.created_by = created_by
        instance.last_message_at = last_message_at
        instance.name = name
        instance.namespace = namespace
        instance.topic_id = topic_id
        instance.type_ = type_
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsTopicResponse:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = int(dict_["createdAt"])
        elif include_empty:
            instance.created_at = 0
        if "createdBy" in dict_ and dict_["createdBy"] is not None:
            instance.created_by = str(dict_["createdBy"])
        elif include_empty:
            instance.created_by = ""
        if "lastMessageAt" in dict_ and dict_["lastMessageAt"] is not None:
            instance.last_message_at = int(dict_["lastMessageAt"])
        elif include_empty:
            instance.last_message_at = 0
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "topicId" in dict_ and dict_["topicId"] is not None:
            instance.topic_id = str(dict_["topicId"])
        elif include_empty:
            instance.topic_id = ""
        if "type" in dict_ and dict_["type"] is not None:
            instance.type_ = str(dict_["type"])
        elif include_empty:
            instance.type_ = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsTopicResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsTopicResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsTopicResponse, List[ModelsTopicResponse], Dict[Any, ModelsTopicResponse]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "createdBy": "created_by",
            "lastMessageAt": "last_message_at",
            "name": "name",
            "namespace": "namespace",
            "topicId": "topic_id",
            "type": "type_",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "createdBy": True,
            "lastMessageAt": True,
            "name": True,
            "namespace": True,
            "topicId": True,
            "type": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service (0.4.14)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model
from accelbyte_py_sdk.core import StrEnum


class ScopeEnum(StrEnum):
    NAMESPACE = "NAMESPACE"
    USER = "USER"


class StatusEnum(StrEnum):
    DRAFT = "DRAFT"
    SENT = "SENT"
    UNSENT = "UNSENT"


class ModelsGetInboxMessagesResponseData(Model):
    """Models get inbox messages response data (models.GetInboxMessagesResponseData)

    Properties:
        created_at: (createdAt) REQUIRED int

        expired_at: (expiredAt) REQUIRED int

        id_: (id) REQUIRED str

        message: (message) REQUIRED Dict[str, Any]

        scope: (scope) REQUIRED Union[str, ScopeEnum]

        sender_id: (senderId) REQUIRED str

        status: (status) REQUIRED Union[str, StatusEnum]

        updated_at: (updatedAt) REQUIRED int

        user_ids: (userIds) REQUIRED List[str]

        category: (category) OPTIONAL str
    """

    # region fields

    created_at: int  # REQUIRED
    expired_at: int  # REQUIRED
    id_: str  # REQUIRED
    message: Dict[str, Any]  # REQUIRED
    scope: Union[str, ScopeEnum]  # REQUIRED
    sender_id: str  # REQUIRED
    status: Union[str, StatusEnum]  # REQUIRED
    updated_at: int  # REQUIRED
    user_ids: List[str]  # REQUIRED
    category: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_created_at(self, value: int) -> ModelsGetInboxMessagesResponseData:
        self.created_at = value
        return self

    def with_expired_at(self, value: int) -> ModelsGetInboxMessagesResponseData:
        self.expired_at = value
        return self

    def with_id(self, value: str) -> ModelsGetInboxMessagesResponseData:
        self.id_ = value
        return self

    def with_message(self, value: Dict[str, Any]) -> ModelsGetInboxMessagesResponseData:
        self.message = value
        return self

    def with_scope(
        self, value: Union[str, ScopeEnum]
    ) -> ModelsGetInboxMessagesResponseData:
        self.scope = value
        return self

    def with_sender_id(self, value: str) -> ModelsGetInboxMessagesResponseData:
        self.sender_id = value
        return self

    def with_status(
        self, value: Union[str, StatusEnum]
    ) -> ModelsGetInboxMessagesResponseData:
        self.status = value
        return self

    def with_updated_at(self, value: int) -> ModelsGetInboxMessagesResponseData:
        self.updated_at = value
        return self

    def with_user_ids(self, value: List[str]) -> ModelsGetInboxMessagesResponseData:
        self.user_ids = value
        return self

    def with_category(self, value: str) -> ModelsGetInboxMessagesResponseData:
        self.category = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "created_at"):
            result["createdAt"] = int(self.created_at)
        elif include_empty:
            result["createdAt"] = 0
        if hasattr(self, "expired_at"):
            result["expiredAt"] = int(self.expired_at)
        elif include_empty:
            result["expiredAt"] = 0
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "message"):
            result["message"] = {str(k0): v0 for k0, v0 in self.message.items()}
        elif include_empty:
            result["message"] = {}
        if hasattr(self, "scope"):
            result["scope"] = str(self.scope)
        elif include_empty:
            result["scope"] = Union[str, ScopeEnum]()
        if hasattr(self, "sender_id"):
            result["senderId"] = str(self.sender_id)
        elif include_empty:
            result["senderId"] = ""
        if hasattr(self, "status"):
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = Union[str, StatusEnum]()
        if hasattr(self, "updated_at"):
            result["updatedAt"] = int(self.updated_at)
        elif include_empty:
            result["updatedAt"] = 0
        if hasattr(self, "user_ids"):
            result["userIds"] = [str(i0) for i0 in self.user_ids]
        elif include_empty:
            result["userIds"] = []
        if hasattr(self, "category"):
            result["category"] = str(self.category)
        elif include_empty:
            result["category"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        created_at: int,
        expired_at: int,
        id_: str,
        message: Dict[str, Any],
        scope: Union[str, ScopeEnum],
        sender_id: str,
        status: Union[str, StatusEnum],
        updated_at: int,
        user_ids: List[str],
        category: Optional[str] = None,
        **kwargs,
    ) -> ModelsGetInboxMessagesResponseData:
        instance = cls()
        instance.created_at = created_at
        instance.expired_at = expired_at
        instance.id_ = id_
        instance.message = message
        instance.scope = scope
        instance.sender_id = sender_id
        instance.status = status
        instance.updated_at = updated_at
        instance.user_ids = user_ids
        if category is not None:
            instance.category = category
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsGetInboxMessagesResponseData:
        instance = cls()
        if not dict_:
            return instance
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = int(dict_["createdAt"])
        elif include_empty:
            instance.created_at = 0
        if "expiredAt" in dict_ and dict_["expiredAt"] is not None:
            instance.expired_at = int(dict_["expiredAt"])
        elif include_empty:
            instance.expired_at = 0
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "message" in dict_ and dict_["message"] is not None:
            instance.message = {str(k0): v0 for k0, v0 in dict_["message"].items()}
        elif include_empty:
            instance.message = {}
        if "scope" in dict_ and dict_["scope"] is not None:
            instance.scope = str(dict_["scope"])
        elif include_empty:
            instance.scope = Union[str, ScopeEnum]()
        if "senderId" in dict_ and dict_["senderId"] is not None:
            instance.sender_id = str(dict_["senderId"])
        elif include_empty:
            instance.sender_id = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = Union[str, StatusEnum]()
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = int(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = 0
        if "userIds" in dict_ and dict_["userIds"] is not None:
            instance.user_ids = [str(i0) for i0 in dict_["userIds"]]
        elif include_empty:
            instance.user_ids = []
        if "category" in dict_ and dict_["category"] is not None:
            instance.category = str(dict_["category"])
        elif include_empty:
            instance.category = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsGetInboxMessagesResponseData]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsGetInboxMessagesResponseData]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsGetInboxMessagesResponseData,
        List[ModelsGetInboxMessagesResponseData],
        Dict[Any, ModelsGetInboxMessagesResponseData],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "createdAt": "created_at",
            "expiredAt": "expired_at",
            "id": "id_",
            "message": "message",
            "scope": "scope",
            "senderId": "sender_id",
            "status": "status",
            "updatedAt": "updated_at",
            "userIds": "user_ids",
            "category": "category",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "createdAt": True,
            "expiredAt": True,
            "id": True,
            "message": True,
            "scope": True,
            "senderId": True,
            "status": True,
            "updatedAt": True,
            "userIds": True,
            "category": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "scope": ["NAMESPACE", "USER"],
            "status": ["DRAFT", "SENT", "UNSENT"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: model.j2

# AccelByte Gaming Services Chat Service (0.4.14)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from accelbyte_py_sdk.core import Model


class ModelsDictionaryWordChanges(Model):
    """Models dictionary word changes (models.DictionaryWordChanges)

    Properties:
        added: (added) REQUIRED List[str]

        failed: (failed) REQUIRED List[str]

        ignored: (ignored) REQUIRED List[str]

        replaced: (replaced) REQUIRED List[str]

        unchanged: (unchanged) REQUIRED List[str]
    """

    # region fields

    added: List[str]  # REQUIRED
    failed: List[str]  # REQUIRED
    ignored: List[str]  # REQUIRED
    replaced: List[str]  # REQUIRED
    unchanged: List[str]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_added(self, value: List[str]) -> ModelsDictionaryWordChanges:
        self.added = value
        return self

    def with_failed(self, value: List[str]) -> ModelsDictionaryWordChanges:
        self.failed = value
        return self

    def with_ignored(self, value: List[str]) -> ModelsDictionaryWordChanges:
        self.ignored = value
        return self

    def with_replaced(self, value: List[str]) -> ModelsDictionaryWordChanges:
        self.replaced = value
        return self

    def with_unchanged(self, value: List[str]) -> ModelsDictionaryWordChanges:
        self.unchanged = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "added"):
            result["added"] = [str(i0) for i0 in self.added]
        elif include_empty:
            result["added"] = []
        if hasattr(self, "failed"):
            result["failed"] = [str(i0) for i0 in self.failed]
        elif include_empty:
            result["failed"] = []
        if hasattr(self, "ignored"):
            result["ignored"] = [str(i0) for i0 in self.ignored]
        elif include_empty:
            result["ignored"] = []
        if hasattr(self, "replaced"):
            result["replaced"] = [str(i0) for i0 in self.replaced]
        elif include_empty:
            result["replaced"] = []
        if hasattr(self, "unchanged"):
            result["unchanged"] = [str(i0) for i0 in self.unchanged]
        elif include_empty:
            result["unchanged"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        added: List[str],
        failed: List[str],
        ignored: List[str],
        replaced: List[str],
        unchanged: List[str],
        **kwargs,
    ) -> ModelsDictionaryWordChanges:
        instance = cls()
        instance.added = added
        instance.failed = failed
        instance.ignored = ignored
        instance.replaced = replaced
        instance.unchanged = unchanged
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsDictionaryWordChanges:
        instance = cls()
        if not dict_:
            return instance
        if "added" in dict_ and dict_["added"] is not None:
            instance.added = [str(i0) for i0 in dict_["added"]]
        elif include_empty:
            instance.added = []
        if "failed" in dict_ and dict_["failed"] is not None:
            instance.failed = [str(i0) for i0 in dict_["failed"]]
        elif include_empty:
            instance.failed = []
        if "ignored" in dict_ and dict_["ignored"] is not None:
            instance.ignored = [str(i0) for i0 in dict_["ignored"]]
        elif include_empty:
            instance.ignored = []
        if "replaced" in dict_ and dict_["replaced"] is not None:
            instance.replaced = [str(i0) for i0 in dict_["replaced"]]
        elif include_empty:
            instance.replaced = []
        if "unchanged" in dict_ and dict_["unchanged"] is not None:
            instance.unchanged = [str(i0) for i0 in dict_["unchanged"]]
        elif include_empty:
            instance.unchanged = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsDictionaryWordChanges]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsDictionaryWordChanges]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsDictionaryWordChanges,
        List[ModelsDictionaryWordChanges],
        Dict[Any, ModelsDictionaryWordChanges],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "added": "added",
            "failed": "failed",
            "ignored": "ignored",
            "replaced": "replaced",
            "unchanged": "unchanged",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "added": True,
            "failed": True,
            "ignored": True,
            "replaced": True,
            "unchanged": True,
        }

    # endregion static methods
